from django.conf import settings
from django.conf.urls import include, url

from django.contrib import admin
admin.autodiscover()

from .views import admin_required, login, login_local, logout, home, health_json, menu_json, hobo
from .urls_utils import decorated_includes
from .environment.urls import urlpatterns as environment_urls
from .franceconnect.urls import urlpatterns as franceconnect_urls
from .matomo.urls import urlpatterns as matomo_urls
from .profile.urls import urlpatterns as profile_urls
from .theme.urls import urlpatterns as theme_urls
from .emails.urls import urlpatterns as emails_urls

urlpatterns = [
    url(r'^$', home, name='home'),
    url(r'^sites/', decorated_includes(admin_required,
                                       include(environment_urls))),
    url(r'^profile/', decorated_includes(admin_required,
                                             include(profile_urls))),
    url(r'^franceconnect/',
        decorated_includes(admin_required, include(franceconnect_urls))),
    url(r'^matomo/',
        decorated_includes(admin_required, include(matomo_urls))),
    url(r'^theme/', decorated_includes(admin_required,
                                             include(theme_urls))),
    url(r'^emails/', decorated_includes(admin_required, include(emails_urls))),
    url(r'^api/health/$', health_json, name='health-json'),
    url(r'^menu.json$', menu_json, name='menu_json'),
    url(r'^hobos.json$', hobo),
    url(r'^admin/', include(admin.site.urls)),
]

# add authentication patterns
urlpatterns += [
    url(r'^logout/$', logout, name='logout'),
    url(r'^login/$', login, name='auth_login'),
    url(r'^login/local/$', login_local), # to be used as backup, in case of idp down
    url(r'^accounts/mellon/', include('mellon.urls')),
]

if 'hobo.contrib.ozwillo' in settings.INSTALLED_APPS:
    urlpatterns += [
        url(r'ozwillo/', include('hobo.contrib.ozwillo.urls')),
    ]
